@@ -18,26 +18,26 @@ impl CommandInfo {
 
     pub fn default_commands() -> Vec<CommandInfo> {
         vec![
-            CommandInfo::new("quit", "Quit the program."),
-            CommandInfo::new("dquit", "Quit the program without saving."),
-            CommandInfo::new("xquit", "Save and quit the program."),
-            CommandInfo::new("save", "Save the current file."),
-            CommandInfo::new("saveas", "Save the current file as a new file."),
-            CommandInfo::new("csave", "Save the comments."),
-            CommandInfo::new("help", "Display the help page."),
-            CommandInfo::new("open", "Open a file."),
-            CommandInfo::new("log", "Open the log."),
-            CommandInfo::new("run", "Run a command."),
-            CommandInfo::new("ftext", "Find text."),
-            CommandInfo::new("fsym", "Find a symbol."),
-            CommandInfo::new("fcom", "Find a comment."),
-            CommandInfo::new("ecom", "Edit a comment."),
-            CommandInfo::new("text", "Insert text."),
-            CommandInfo::new("patch", "Patch assembly."),
-            CommandInfo::new("jump", "Jump to address."),
-            CommandInfo::new("view", "Switch between text and assembly."),
-            CommandInfo::new("undo", "Undo the last change."),
-            CommandInfo::new("redo", "Redo the last change."),
+            CommandInfo::new("quit", t!("app.commands.quit")),
+            CommandInfo::new("dquit", t!("app.commands.dquit")),
+            CommandInfo::new("xquit", t!("app.commands.xquit")),
+            CommandInfo::new("save", t!("app.commands.save")),
+            CommandInfo::new("saveas", t!("app.commands.saveas")),
+            CommandInfo::new("csave", t!("app.commands.csave")),
+            CommandInfo::new("help", t!("app.commands.help")),
+            CommandInfo::new("open", t!("app.commands.open")),
+            CommandInfo::new("log", t!("app.commands.log")),
+            CommandInfo::new("run", t!("app.commands.run")),
+            CommandInfo::new("ftext", t!("app.commands.ftext")),
+            CommandInfo::new("fsym", t!("app.commands.fsym")),
+            CommandInfo::new("fcom", t!("app.commands.fcom")),
+            CommandInfo::new("ecom", t!("app.commands.ecom")),
+            CommandInfo::new("text", t!("app.commands.text")),
+            CommandInfo::new("patch", t!("app.commands.patch")),
+            CommandInfo::new("jump", t!("app.commands.jump")),
+            CommandInfo::new("view", t!("app.commands.view")),
+            CommandInfo::new("undo", t!("app.commands.undo")),
+            CommandInfo::new("redo", t!("app.commands.redo")),
         ]
     }
 
