@@ -6,8 +6,8 @@ pub struct FrameInfo {
     pub status_bar: Rect,
     pub scroll_bar: Rect,
     pub address_view: Rect,
-    pub hex_view: Rect,
-    pub info_view: Rect,
+    pub hex_view: Option<Rect>,
+    pub info_view: Option<Rect>,
     pub info_view_frame_info: InfoViewFrameInfo,
     pub blocks_per_row: usize,
     pub scroll: usize,
