@@ -39,6 +39,6 @@ fn main() {
     terminal.show_cursor().expect(&t!("errors.show_cursor"));
 
     if let Err(err) = res {
-        println!("{:?}", err)
+        println!("{err:?}")
     }
 }
